# Generated by Django 2.2 on 2020-03-06 21:56

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django_currentuser.db.models.fields
import django_currentuser.middleware


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0026_auto_20200305_1032'),
    ]

    operations = [
        migrations.AlterField(
            model_name='accessory',
            name='owner',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='archive',
            name='owner',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='bulkfilm',
            name='owner',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='camera',
            name='owner',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='enlarger',
            name='owner',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='film',
            name='owner',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='filter',
            name='owner',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='flash',
            name='owner',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='lens',
            name='owner',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='mountadapter',
            name='owner',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='negative',
            name='owner',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='negativesize',
            name='area',
            field=models.PositiveIntegerField(
                blank=True, editable=False, help_text='Area of this negative size in sq. mm', null=True),
        ),
        migrations.AlterField(
            model_name='negativesize',
            name='aspect_ratio',
            field=models.DecimalField(blank=True, decimal_places=2, editable=False,
                                      help_text='Aspect ratio of this negative size, expressed as a single decimal (e.g. 3:2 is expressed as 1.5)', max_digits=4, null=True),
        ),
        migrations.AlterField(
            model_name='negativesize',
            name='crop_factor',
            field=models.DecimalField(blank=True, decimal_places=2, editable=False,
                                      help_text='Crop factor of this negative size', max_digits=4, null=True),
        ),
        migrations.AlterField(
            model_name='order',
            name='owner',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='person',
            name='owner',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='print',
            name='owner',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='repair',
            name='owner',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='scan',
            name='owner',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='series',
            name='owner',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='shutterspeed',
            name='duration',
            field=models.DecimalField(decimal_places=5, editable=False,
                                      help_text='Shutter speed in decimal notation, e.g. 0.04', max_digits=9),
        ),
        migrations.AlterField(
            model_name='teleconverter',
            name='owner',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
    ]



# Generated by Django 2.2.12 on 2020-05-21 20:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0058_auto_20200517_2016'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cameramodel',
            name='exif_lenstype',
        ),
        migrations.RemoveField(
            model_name='cameramodel',
            name='formula',
        ),
        migrations.RemoveField(
            model_name='lensmodel',
            name='exif_lenstype',
        ),
        migrations.RemoveField(
            model_name='lensmodel',
            name='formula',
        ),
    ]



from django.urls import path
from django.views.generic import TemplateView
from django.conf import settings
from django.conf.urls.static import static

from schema import views

app_name = 'schema'
urlpatterns = [

    # Static pages
    path('', TemplateView.as_view(template_name='index.html'), name='index'),
    path('stats', views.StatsView.as_view(), name='stats'),
    path('mystats', views.MyStatsView.as_view(), name='mystats'),
    path('search/', views.SearchView.as_view(), name='search'),

    path('tag/', views.TagList.as_view(), name='tag-list'),
    path('tag/<slug:slug>', views.TagDetail.as_view(), name='tag-detail'),
    path('tag-autocomplete/', views.TagAutocomplete.as_view(),
         name='tag-autocomplete'),

    path('accessory/', views.AccessoryList.as_view(), name='accessory-list'),
    path('accessory/<int:id_owner>', views.AccessoryDetail.as_view(),
         name='accessory-detail'),
    path('accessory/create/', views.AccessoryCreate.as_view(),
         name='accessory-create'),
    path('accessory/<int:id_owner>/update',
         views.AccessoryUpdate.as_view(), name='accessory-update'),

    path('archive/', views.ArchiveList.as_view(), name='archive-list'),
    path('archive/<int:id_owner>',
         views.ArchiveDetail.as_view(), name='archive-detail'),
    path('archive/create/', views.ArchiveCreate.as_view(), name='archive-create'),
    path('archive/<int:id_owner>/update',
         views.ArchiveUpdate.as_view(), name='archive-update'),

    path('battery/', views.BatteryList.as_view(), name='battery-list'),
    path('battery/<slug:slug>', views.BatteryDetail.as_view(), name='battery-detail'),
    path('battery/create/', views.BatteryCreate.as_view(), name='battery-create'),
    path('battery/<slug:slug>/update',
         views.BatteryUpdate.as_view(), name='battery-update'),

    path('bulkfilm/', views.BulkFilmList.as_view(), name='bulkfilm-list'),
    path('bulkfilm/<int:id_owner>',
         views.BulkFilmDetail.as_view(), name='bulkfilm-detail'),
    path('bulkfilm/create/', views.BulkFilmCreate.as_view(), name='bulkfilm-create'),
    path('bulkfilm/<int:id_owner>/update',
         views.BulkFilmUpdate.as_view(), name='bulkfilm-update'),

    path('camera/', views.CameraList.as_view(), name='camera-list'),
    path('camera/<int:id_owner>', views.CameraDetail.as_view(), name='camera-detail'),
    path('camera/create/', views.CameraCreate.as_view(), name='camera-create'),
    path('camera/<int:id_owner>/update',
         views.CameraUpdate.as_view(), name='camera-update'),
    path('camera/<int:id_owner>/sell',
         views.CameraSell.as_view(), name='camera-sell'),

    path('cameramodel/', views.CameraModelList.as_view(), name='cameramodel-list'),
    path('cameramodel/<slug:slug>', views.CameraModelDetail.as_view(),
         name='cameramodel-detail'),
    path('cameramodel/create/', views.CameraModelCreate.as_view(),
         name='cameramodel-create'),
    path('cameramodel/<slug:slug>/update',
         views.CameraModelUpdate.as_view(), name='cameramodel-update'),

    path('developer/', views.DeveloperList.as_view(), name='developer-list'),
    path('developer/<slug:slug>', views.DeveloperDetail.as_view(),
         name='developer-detail'),
    path('developer/create/', views.DeveloperCreate.as_view(),
         name='developer-create'),
    path('developer/<slug:slug>/update',
         views.DeveloperUpdate.as_view(), name='developer-update'),

    path('enlargermodel/', views.EnlargerModelList.as_view(),
         name='enlargermodel-list'),
    path('enlargermodel/<slug:slug>', views.EnlargerModelDetail.as_view(),
         name='enlargermodel-detail'),
    path('enlargermodel/create/', views.EnlargerModelCreate.as_view(),
         name='enlargermodel-create'),
    path('enlargermodel/<slug:slug>/update',
         views.EnlargerModelUpdate.as_view(), name='enlargermodel-update'),

    path('enlarger/', views.EnlargerList.as_view(), name='enlarger-list'),
    path('enlarger/<int:id_owner>',
         views.EnlargerDetail.as_view(), name='enlarger-detail'),
    path('enlarger/create/', views.EnlargerCreate.as_view(), name='enlarger-create'),
    path('enlarger/<int:id_owner>/update',
         views.EnlargerUpdate.as_view(), name='enlarger-update'),

    path('filmstock/', views.FilmStockList.as_view(), name='filmstock-list'),
    path('filmstock/<slug:slug>', views.FilmStockDetail.as_view(),
         name='filmstock-detail'),
    path('filmstock/create/', views.FilmStockCreate.as_view(),
         name='filmstock-create'),
    path('filmstock/<slug:slug>/update',
         views.FilmStockUpdate.as_view(), name='filmstock-update'),

    path('filter/', views.FilterList.as_view(), name='filter-list'),
    path('filter/<int:pk>', views.FilterDetail.as_view(), name='filter-detail'),
    path('filter/create/', views.FilterCreate.as_view(), name='filter-create'),
    path('filter/<int:pk>/update',
         views.FilterUpdate.as_view(), name='filter-update'),

    path('flash/', views.FlashList.as_view(), name='flash-list'),
    path('flash/<int:id_owner>', views.FlashDetail.as_view(), name='flash-detail'),
    path('flash/create/', views.FlashCreate.as_view(), name='flash-create'),
    path('flash/<int:id_owner>/update',
         views.FlashUpdate.as_view(), name='flash-update'),

    path('flashmodel/', views.FlashModelList.as_view(), name='flashmodel-list'),
    path('flashmodel/<slug:slug>', views.FlashModelDetail.as_view(),
         name='flashmodel-detail'),
    path('flashmodel/create/', views.FlashModelCreate.as_view(),
         name='flashmodel-create'),
    path('flashmodel/<slug:slug>/update',
         views.FlashModelUpdate.as_view(), name='flashmodel-update'),

    path('format/', views.FormatList.as_view(), name='format-list'),
    path('format/<int:pk>', views.FormatDetail.as_view(), name='format-detail'),
    path('format/create/', views.FormatCreate.as_view(), name='format-create'),
    path('format/<int:pk>/update',
         views.FormatUpdate.as_view(), name='format-update'),

    path('lens/', views.LensList.as_view(), name='lens-list'),
    path('lens/<int:id_owner>', views.LensDetail.as_view(), name='lens-detail'),
    path('lens/create/', views.LensCreate.as_view(), name='lens-create'),
    path('lens/<int:id_owner>/update',
         views.LensUpdate.as_view(), name='lens-update'),
    path('lens/<int:id_owner>/sell', views.LensSell.as_view(), name='lens-sell'),

    path('lensmodel/', views.LensModelList.as_view(), name='lensmodel-list'),
    path('lensmodel/<slug:slug>', views.LensModelDetail.as_view(),
         name='lensmodel-detail'),
    path('lensmodel/create/', views.LensModelCreate.as_view(),
         name='lensmodel-create'),
    path('lensmodel/<slug:slug>/update',
         views.LensModelUpdate.as_view(), name='lensmodel-update'),

    path('manufacturer/', views.ManufacturerList.as_view(),
         name='manufacturer-list'),
    path('manufacturer/<slug:slug>', views.ManufacturerDetail.as_view(),
         name='manufacturer-detail'),
    path('manufacturer/create/', views.ManufacturerCreate.as_view(),
         name='manufacturer-create'),
    path('manufacturer/<slug:slug>/update',
         views.ManufacturerUpdate.as_view(), name='manufacturer-update'),

    path('mount/', views.MountList.as_view(), name='mount-list'),
    path('mount/<slug:slug>', views.MountDetail.as_view(), name='mount-detail'),
    path('mount/create/', views.MountCreate.as_view(), name='mount-create'),
    path('mount/<slug:slug>/update',
         views.MountUpdate.as_view(), name='mount-update'),

    path('mountadapter/', views.MountAdapterList.as_view(),
         name='mountadapter-list'),
    path('mountadapter/<int:id_owner>', views.MountAdapterDetail.as_view(),
         name='mountadapter-detail'),
    path('mountadapter/create/', views.MountAdapterCreate.as_view(),
         name='mountadapter-create'),
    path('mountadapter/<int:id_owner>/update',
         views.MountAdapterUpdate.as_view(), name='mountadapter-update'),

    path('negativesize/', views.NegativeSizeList.as_view(),
         name='negativesize-list'),
    path('negativesize/<int:pk>', views.NegativeSizeDetail.as_view(),
         name='negativesize-detail'),
    path('negativesize/create/', views.NegativeSizeCreate.as_view(),
         name='negativesize-create'),
    path('negativesize/<int:pk>/update',
         views.NegativeSizeUpdate.as_view(), name='negativesize-update'),

    path('order/', views.OrderList.as_view(), name='order-list'),
    path('order/<int:id_owner>', views.OrderDetail.as_view(), name='order-detail'),
    path('order/create/', views.OrderCreate.as_view(), name='order-create'),
    path('order/<int:id_owner>/update',
         views.OrderUpdate.as_view(), name='order-update'),

    path('paperstock/', views.PaperStockList.as_view(), name='paperstock-list'),
    path('paperstock/<int:pk>', views.PaperStockDetail.as_view(),
         name='paperstock-detail'),
    path('paperstock/create/', views.PaperStockCreate.as_view(),
         name='paperstock-create'),
    path('paperstock/<int:pk>/update',
         views.PaperStockUpdate.as_view(), name='paperstock-update'),

    path('person/', views.PersonList.as_view(), name='person-list'),
    path('person/<int:id_owner>', views.PersonDetail.as_view(), name='person-detail'),
    path('person/create/', views.PersonCreate.as_view(), name='person-create'),
    path('person/<int:id_owner>/update',
         views.PersonUpdate.as_view(), name='person-update'),

    path('print/', views.PrintList.as_view(), name='print-list'),
    path('print/<int:id_owner>', views.PrintDetail.as_view(), name='print-detail'),
    path('print/create/', views.PrintCreate.as_view(), name='print-create'),
    path('print/<int:id_owner>/update',
         views.PrintUpdate.as_view(), name='print-update'),

    path('process/', views.ProcessList.as_view(), name='process-list'),
    path('process/<int:pk>', views.ProcessDetail.as_view(), name='process-detail'),
    path('process/create/', views.ProcessCreate.as_view(), name='process-create'),
    path('process/<int:pk>/update',
         views.ProcessUpdate.as_view(), name='process-update'),

    path('scan/', views.ScanList.as_view(), name='scan-list'),
    path('scan/<uuid:uuid>', views.ScanDetail.as_view(), name='scan-detail'),
    path('scan/create/', views.ScanCreate.as_view(), name='scan-create'),
    path('scan/<uuid:uuid>/update',
         views.ScanUpdate.as_view(), name='scan-update'),

    path('negative/', views.NegativeList.as_view(), name='negative-list'),
    path('negative/<int:id_owner>',
         views.NegativeDetail.as_view(), name='negative-detail'),
    path('negative/create/', views.NegativeCreate.as_view(), name='negative-create'),
    path('negative/<int:id_owner>/update',
         views.NegativeUpdate.as_view(), name='negative-update'),

    path('film/', views.FilmList.as_view(), name='film-list'),
    path('film/<int:id_owner>', views.FilmDetail.as_view(), name='film-detail'),
    path('film/create/', views.FilmCreate.as_view(), name='film-create'),
    path('film/<int:id_owner>/update',
         views.FilmUpdate.as_view(), name='film-update'),
    path('film/<int:id_owner>/load', views.FilmLoad.as_view(), name='film-load'),
    path('film/<int:id_owner>/develop',
         views.FilmDevelop.as_view(), name='film-develop'),
    path('film/<int:id_owner>/archive',
         views.FilmArchive.as_view(), name='film-archive'),

    path('teleconverter/', views.TeleconverterList.as_view(),
         name='teleconverter-list'),
    path('teleconverter/<int:id_owner>',
         views.TeleconverterDetail.as_view(), name='teleconverter-detail'),
    path('teleconverter/create/', views.TeleconverterCreate.as_view(),
         name='teleconverter-create'),
    path('teleconverter/<int:id_owner>/update',
         views.TeleconverterUpdate.as_view(), name='teleconverter-update'),

    path('teleconvertermodel/', views.TeleconverterModelList.as_view(),
         name='teleconvertermodel-list'),
    path('teleconvertermodel/<slug:slug>',
         views.TeleconverterModelDetail.as_view(), name='teleconvertermodel-detail'),
    path('teleconvertermodel/create/', views.TeleconverterModelCreate.as_view(),
         name='teleconvertermodel-create'),
    path('teleconvertermodel/<slug:slug>/update',
         views.TeleconverterModelUpdate.as_view(), name='teleconvertermodel-update'),

    path('toner/', views.TonerList.as_view(), name='toner-list'),
    path('toner/<slug:slug>', views.TonerDetail.as_view(), name='toner-detail'),
    path('toner/create/', views.TonerCreate.as_view(), name='toner-create'),
    path('toner/<slug:slug>/update',
         views.TonerUpdate.as_view(), name='toner-update'),
] + static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)



# Generated by Django 2.2.16 on 2020-11-06 21:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0098_auto_20201028_2117'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='historicalflashprotocol',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicalflashprotocol',
            name='manufacturer',
        ),
        migrations.RemoveField(
            model_name='cameramodel',
            name='flash_metering',
        ),
        migrations.RemoveField(
            model_name='flash',
            name='flash_protocol',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='flash_metering',
        ),
        migrations.DeleteModel(
            name='FlashProtocol',
        ),
        migrations.DeleteModel(
            name='HistoricalFlashProtocol',
        ),
    ]



# Generated by Django 2.2 on 2020-03-27 22:31

import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0048_auto_20200324_0839'),
    ]

    operations = [
        migrations.AddField(
            model_name='cameramodel',
            name='aperture_blades',
            field=models.PositiveIntegerField(
                blank=True, help_text='Number of aperture blades', null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='closest_focus',
            field=models.PositiveIntegerField(
                blank=True, help_text='The closest focus possible with this lens, in cm', null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='coating',
            field=models.CharField(blank=True, choices=[('Uncoated', 'Uncoated'), ('Single coated', 'Single coated'), (
                'Multi coated', 'Multi coated')], help_text='Type of lens coating', max_length=15, null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='elements',
            field=models.PositiveIntegerField(
                blank=True, help_text='Number of optical lens elements', null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='exif_lenstype',
            field=models.CharField(
                blank=True, help_text='EXIF LensID number, if this lens has one officially registered. See documentation at http://www.sno.phy.queensu.ca/~phil/exiftool/TagNames/', max_length=45, null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='filter_thread',
            field=models.DecimalField(
                blank=True, decimal_places=1, help_text='Diameter of lens filter thread, in mm', max_digits=4, null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='formula',
            field=models.CharField(
                blank=True, help_text='Name of the type of lens formula (e.g. Tessar)', max_length=45, null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='groups',
            field=models.PositiveIntegerField(
                blank=True, help_text='Number of optical groups', null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='hood',
            field=models.CharField(
                blank=True, help_text='Model number of the compatible lens hood', max_length=45, null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='image_circle',
            field=models.PositiveIntegerField(
                blank=True, help_text='Diameter of image circle projected by lens, in mm', null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='lens_manufacturer',
            field=models.ForeignKey(blank=True, help_text='Manufacturer of this lens model', null=True,
                                    on_delete=django.db.models.deletion.CASCADE, related_name='lens_manufacturer', to='schema.Manufacturer'),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='lens_model',
            field=models.CharField(
                blank=True, help_text='Model name of this lens', max_length=45, null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='magnification',
            field=models.DecimalField(
                blank=True, decimal_places=3, help_text='Maximum magnification ratio of the lens, expressed like 0.765', max_digits=5, null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='max_aperture',
            field=models.DecimalField(
                blank=True, decimal_places=1, help_text='Maximum (widest) aperture available on this lens (numerical part only, e.g. 2.8)', max_digits=4, null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='max_focal_length',
            field=models.PositiveIntegerField(
                blank=True, help_text='Longest focal length of this lens, in mm', null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='min_aperture',
            field=models.DecimalField(
                blank=True, decimal_places=1, help_text='Minimum (narrowest) aperture available on this lens (numerical part only, e.g. 22)', max_digits=4, null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='min_focal_length',
            field=models.PositiveIntegerField(
                blank=True, help_text='Shortest focal length of this lens, in mm', null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='nominal_max_angle_diag',
            field=models.PositiveIntegerField(blank=True, help_text='Nominal maximum diagonal field of view from manufacturer specs', null=True, validators=[
                                              django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(360)], verbose_name='Max angle of view'),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='nominal_min_angle_diag',
            field=models.PositiveIntegerField(blank=True, help_text='Nominal minimum diagonal field of view from manufacturer specs', null=True, validators=[
                                              django.core.validators.MinValueValidator(0), django.core.validators.MaxValueValidator(360)], verbose_name='Min angle of view'),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='rectilinear',
            field=models.BooleanField(
                blank=True, default=1, help_text='Whether this is a rectilinear lens', null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='zoom',
            field=models.BooleanField(
                blank=True, help_text='Whether this is a zoom lens', null=True),
        ),
    ]



# Generated by Django 2.2 on 2020-04-27 21:11

from django.db import migrations
import taggit.managers


class Migration(migrations.Migration):

    dependencies = [
        ('taggit', '0003_taggeditem_add_unique_index'),
        ('schema', '0052_cameramodel_url'),
    ]

    operations = [
        migrations.AddField(
            model_name='cameramodel',
            name='tags',
            field=taggit.managers.TaggableManager(help_text='A comma-separated list of tags.', through='taggit.TaggedItem', to='taggit.Tag', verbose_name='Tags'),
        ),
        migrations.AddField(
            model_name='developer',
            name='tags',
            field=taggit.managers.TaggableManager(help_text='A comma-separated list of tags.', through='taggit.TaggedItem', to='taggit.Tag', verbose_name='Tags'),
        ),
        migrations.AddField(
            model_name='filmstock',
            name='tags',
            field=taggit.managers.TaggableManager(help_text='A comma-separated list of tags.', through='taggit.TaggedItem', to='taggit.Tag', verbose_name='Tags'),
        ),
        migrations.AddField(
            model_name='lensmodel',
            name='tags',
            field=taggit.managers.TaggableManager(help_text='A comma-separated list of tags.', through='taggit.TaggedItem', to='taggit.Tag', verbose_name='Tags'),
        ),
        migrations.AddField(
            model_name='manufacturer',
            name='tags',
            field=taggit.managers.TaggableManager(help_text='A comma-separated list of tags.', through='taggit.TaggedItem', to='taggit.Tag', verbose_name='Tags'),
        ),
        migrations.AddField(
            model_name='mount',
            name='tags',
            field=taggit.managers.TaggableManager(help_text='A comma-separated list of tags.', through='taggit.TaggedItem', to='taggit.Tag', verbose_name='Tags'),
        ),
        migrations.AddField(
            model_name='paperstock',
            name='tags',
            field=taggit.managers.TaggableManager(help_text='A comma-separated list of tags.', through='taggit.TaggedItem', to='taggit.Tag', verbose_name='Tags'),
        ),
        migrations.AddField(
            model_name='toner',
            name='tags',
            field=taggit.managers.TaggableManager(help_text='A comma-separated list of tags.', through='taggit.TaggedItem', to='taggit.Tag', verbose_name='Tags'),
        ),
    ]



# Generated by Django 2.2 on 2020-03-23 22:03

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django_currentuser.db.models.fields
import django_currentuser.middleware


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('schema', '0044_remove_cameramodel_coupled_metering'),
    ]

    operations = [
        migrations.AddField(
            model_name='cameramodel',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(
                default=django_currentuser.middleware.get_current_authenticated_user, editable=False, null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL),
        ),
    ]



# Generated by Django 2.2.13 on 2020-07-08 21:09

from django.db import migrations
import versatileimagefield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0067_auto_20200707_2125'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cameramodel',
            name='image',
            field=versatileimagefield.fields.VersatileImageField(blank=True, help_text='Image of the camera model', null=True, upload_to=''),
        ),
        migrations.AlterField(
            model_name='lensmodel',
            name='diagram',
            field=versatileimagefield.fields.VersatileImageField(blank=True, help_text='Block diagram of the optics', null=True, upload_to=''),
        ),
        migrations.AlterField(
            model_name='lensmodel',
            name='image',
            field=versatileimagefield.fields.VersatileImageField(blank=True, help_text='Image of the lens model', null=True, upload_to=''),
        ),
    ]



# Generated by Django 2.2 on 2020-03-23 20:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0042_cameramodel_mirror_lockup'),
    ]

    operations = [
        migrations.AlterField(
            model_name='lensmodel',
            name='coating',
            field=models.CharField(blank=True, choices=[('Uncoated', 'Uncoated'), ('Single coated', 'Single coated'), (
                'Multi coated', 'Multi coated')], help_text='Type of lens coating', max_length=15, null=True),
        ),
    ]



from django.urls import path
from django.views.generic import TemplateView
from help.views import ConditionListView

app_name = 'help'
urlpatterns = [

    # Static pages
    path('', TemplateView.as_view(template_name='index.html'), name='help'),
    path('concepts', TemplateView.as_view(template_name='concepts.html'), name='concepts'),
    path('about', TemplateView.as_view(template_name='about.html'), name='about'),
    path('faq', TemplateView.as_view(template_name='faq.html'), name='faq'),
    path('condition', ConditionListView.as_view(), name='condition-list'),
]



# Generated by Django 2.2.13 on 2020-06-10 21:31

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0063_closest_focus'),
    ]

    operations = [
        migrations.AlterField(
            model_name='camera',
            name='condition',
            field=models.ForeignKey(blank=True, help_text='Condition of this camera. Refer to <a href="/help/condition">condition grading</a>', null=True, on_delete=django.db.models.deletion.CASCADE, to='schema.Condition'),
        ),
        migrations.AlterField(
            model_name='lens',
            name='condition',
            field=models.ForeignKey(blank=True, help_text='Condition of this lens. Refer to <a href="/help/condition">condition grading</a>', null=True, on_delete=django.db.models.deletion.CASCADE, to='schema.Condition'),
        ),
    ]



from django.db import migrations
from django.db.models import Max, Min


def populate_shutter_speeds(apps, schema_editor):
    cameramodel = apps.get_model('schema', 'CameraModel')

    for row in cameramodel.objects.all():
        if row.fastest_shutter_speed is None:
            row.fastest_shutter_speed = row.shutter_speeds.order_by(
                'duration').first()
        if row.slowest_shutter_speed is None:
            row.slowest_shutter_speed = row.shutter_speeds.order_by(
                '-duration').first()
        row.save()


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0079_auto_20200827_2049'),
    ]

    operations = [
        # omit reverse_code=... if you don't want the migration to be reversible.
        migrations.RunPython(populate_shutter_speeds,
                             reverse_code=migrations.RunPython.noop),
    ]



# Generated by Django 2.2.16 on 2020-10-09 19:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0088_auto_20201012_1422'),
    ]

    operations = [
        migrations.AddField(
            model_name='cameramodel',
            name='image_attribution',
            field=models.CharField(blank=True, help_text='Author of this image', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='cameramodel',
            name='image_attribution_url',
            field=models.URLField(blank=True, help_text='Attribution URL for this image', null=True),
        ),
        migrations.AddField(
            model_name='historicalcameramodel',
            name='image_attribution',
            field=models.CharField(blank=True, help_text='Author of this image', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='historicalcameramodel',
            name='image_attribution_url',
            field=models.URLField(blank=True, help_text='Attribution URL for this image', null=True),
        ),
        migrations.AddField(
            model_name='historicallensmodel',
            name='diagram_attribution',
            field=models.CharField(blank=True, help_text='Author of this diagram', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='historicallensmodel',
            name='diagram_attribution_url',
            field=models.URLField(blank=True, help_text='Attribution URL for this diagram', null=True),
        ),
        migrations.AddField(
            model_name='historicallensmodel',
            name='image_attribution',
            field=models.CharField(blank=True, help_text='Author of this image', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='historicallensmodel',
            name='image_attribution_url',
            field=models.URLField(blank=True, help_text='Attribution URL for this image', null=True),
        ),
        migrations.AddField(
            model_name='lensmodel',
            name='diagram_attribution',
            field=models.CharField(blank=True, help_text='Author of this diagram', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='lensmodel',
            name='diagram_attribution_url',
            field=models.URLField(blank=True, help_text='Attribution URL for this diagram', null=True),
        ),
        migrations.AddField(
            model_name='lensmodel',
            name='image_attribution',
            field=models.CharField(blank=True, help_text='Author of this image', max_length=50, null=True),
        ),
        migrations.AddField(
            model_name='lensmodel',
            name='image_attribution_url',
            field=models.URLField(blank=True, help_text='Attribution URL for this image', null=True),
        ),
    ]



# Generated by Django 2.2.16 on 2020-10-12 14:22

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0087_auto_20201002_1825'),
    ]

    operations = [
        migrations.AlterField(
            model_name='camera',
            name='condition_notes',
            field=models.TextField(blank=True, help_text='Description of condition', null=True),
        ),
        migrations.AlterField(
            model_name='camera',
            name='notes',
            field=models.TextField(blank=True, help_text='Freeform text field for extra notes', null=True),
        ),
        migrations.AlterField(
            model_name='cameramodel',
            name='notes',
            field=models.TextField(blank=True, help_text='Freeform text field for extra notes', null=True),
        ),
        migrations.AlterField(
            model_name='film',
            name='development_notes',
            field=models.TextField(blank=True, help_text='Extra freeform notes about the development process', null=True),
        ),
        migrations.AlterField(
            model_name='historicalcameramodel',
            name='notes',
            field=models.TextField(blank=True, help_text='Freeform text field for extra notes', null=True),
        ),
        migrations.AlterField(
            model_name='historicallensmodel',
            name='notes',
            field=models.TextField(blank=True, help_text='Freeform notes field', null=True),
        ),
        migrations.AlterField(
            model_name='historicalmount',
            name='notes',
            field=models.TextField(blank=True, help_text='Freeform notes field', null=True),
        ),
        migrations.AlterField(
            model_name='lens',
            name='condition_notes',
            field=models.TextField(blank=True, help_text='Description of condition', null=True),
        ),
        migrations.AlterField(
            model_name='lens',
            name='notes',
            field=models.TextField(blank=True, help_text='Freeform notes field', null=True),
        ),
        migrations.AlterField(
            model_name='lensmodel',
            name='notes',
            field=models.TextField(blank=True, help_text='Freeform notes field', null=True),
        ),
        migrations.AlterField(
            model_name='mount',
            name='notes',
            field=models.TextField(blank=True, help_text='Freeform notes field', null=True),
        ),
        migrations.AlterField(
            model_name='mountadapter',
            name='notes',
            field=models.TextField(blank=True, help_text='Freeform notes', null=True),
        ),
        migrations.AlterField(
            model_name='negative',
            name='notes',
            field=models.TextField(blank=True, help_text='Extra freeform notes about this exposure', null=True),
        ),
        migrations.AlterField(
            model_name='print',
            name='notes',
            field=models.TextField(blank=True, help_text='Freeform notes about this print, e.g. dodging, burning & complex toning', null=True),
        ),
    ]



# Generated by Django 2.2.12 on 2020-05-15 15:37

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0056_auto_20200514_1120'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='camera',
            name='display_lens',
        ),
    ]



# Generated by Django 2.2.12 on 2020-05-17 20:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0057_remove_camera_display_lens'),
    ]

    operations = [
        migrations.AddField(
            model_name='filter',
            name='shortname',
            field=models.CharField(blank=True, help_text='Filter type shortname (e.g. Red, CPL, UV)', max_length=45, null=True),
        ),
        migrations.AlterField(
            model_name='filter',
            name='type',
            field=models.CharField(help_text='Filter type (e.g. Red, Circular polariser, Ultraviolet)', max_length=45),
        ),
    ]



# Generated by Django 2.2.9 on 2020-03-17 14:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0032_battery_compatible_with'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='battery',
            name='other_names',
        ),
        migrations.AlterField(
            model_name='battery',
            name='compatible_with',
            field=models.ManyToManyField(
                blank=True, help_text='Batteries that are compatible with this one', to='schema.Battery'),
        ),
    ]



from django import template
from django.utils.safestring import mark_safe
from datetime import date

register = template.Library()


@register.filter(is_safe=True)
def aperture(obj):
    if obj:
        newstr = mark_safe(obj.replace('f/', '<em>f</em>/'))
        return newstr


@register.filter(is_safe=True)
def shutter(obj):
    if obj:
        mystr = str(obj)
        newstr = mark_safe(mystr.replace('1/', '&sup1;/'))
        return newstr

@register.filter(is_safe=True)
def sign(obj):
    if obj > 0:
        mystr = '+' + str(obj)
    elif obj == 0:
        mystr = '&plusmn;' + str(obj)
    else:
        mystr = str(obj)
    return mark_safe(mystr)

@register.filter(is_safe=True)
def yearssince(obj):
    currentyear = '{:04d}'.format(date.today().year)
    diff = int(currentyear) - int(obj)
    return "{} years ago".format(diff)



# Generated by Django 2.2.14 on 2020-08-25 19:54

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import simple_history.models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('schema', '0075_auto_20200825_1920'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='battery',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='battery',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='battery',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='battery',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='cameramodel',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='cameramodel',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='cameramodel',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='cameramodel',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='developer',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='developer',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='developer',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='developer',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='filmstock',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='filmstock',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='filmstock',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='filmstock',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='flashprotocol',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='flashprotocol',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='flashprotocol',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='flashprotocol',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='format',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='format',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='format',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='format',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicalbattery',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicalbattery',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicalbattery',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicalbattery',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicaldeveloper',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicaldeveloper',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicaldeveloper',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicaldeveloper',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicalfilmstock',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicalfilmstock',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicalfilmstock',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicalfilmstock',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicalflashprotocol',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicalflashprotocol',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicalflashprotocol',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicalflashprotocol',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicalformat',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicalformat',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicalformat',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicalformat',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicallensmodel',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicallensmodel',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicallensmodel',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicallensmodel',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicalmanufacturer',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicalmanufacturer',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicalmanufacturer',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicalmanufacturer',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicalmount',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicalmount',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicalmount',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicalmount',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicalnegativesize',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicalnegativesize',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicalnegativesize',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicalnegativesize',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicalpaperstock',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicalpaperstock',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicalpaperstock',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicalpaperstock',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicaltoner',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicaltoner',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicaltoner',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicaltoner',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='lensmodel',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='lensmodel',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='lensmodel',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='lensmodel',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='manufacturer',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='manufacturer',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='manufacturer',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='manufacturer',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='mount',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='mount',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='mount',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='mount',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='negativesize',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='negativesize',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='negativesize',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='negativesize',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='paperstock',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='paperstock',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='paperstock',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='paperstock',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='toner',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='toner',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='toner',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='toner',
            name='updated_by',
        ),
        migrations.CreateModel(
            name='HistoricalProcess',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('name', models.CharField(db_index=True, help_text='Name of this developmenmt process (e.g. C-41, E-6)', max_length=25)),
                ('colour', models.BooleanField(blank=True, help_text='Whether this is a colour process', null=True)),
                ('positive', models.BooleanField(blank=True, help_text='Whether this is a positive/reversal process', null=True)),
                ('history_id', models.AutoField(primary_key=True, serialize=False)),
                ('history_date', models.DateTimeField()),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('history_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical process',
                'ordering': ('-history_date', '-history_id'),
                'get_latest_by': 'history_date',
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
    ]



# Generated by Django 2.2.4 on 2019-12-17 23:03

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('schema', '0017_auto_20191108_1224'),
    ]

    operations = [
        migrations.AddField(
            model_name='accessory',
            name='id_owner',
            field=models.PositiveIntegerField(
                blank=True, help_text='Per-user incrementing number', null=True),
        ),
        migrations.AddField(
            model_name='archive',
            name='id_owner',
            field=models.PositiveIntegerField(
                blank=True, help_text='Per-user incrementing number', null=True),
        ),
        migrations.AddField(
            model_name='bulkfilm',
            name='id_owner',
            field=models.PositiveIntegerField(
                blank=True, help_text='Per-user incrementing number', null=True),
        ),
        migrations.AddField(
            model_name='camera',
            name='id_owner',
            field=models.PositiveIntegerField(
                blank=True, help_text='Per-user incrementing number', null=True),
        ),
        migrations.AddField(
            model_name='enlarger',
            name='id_owner',
            field=models.PositiveIntegerField(
                blank=True, help_text='Per-user incrementing number', null=True),
        ),
        migrations.AddField(
            model_name='film',
            name='id_owner',
            field=models.PositiveIntegerField(
                blank=True, help_text='Per-user incrementing number', null=True),
        ),
        migrations.AddField(
            model_name='filter',
            name='id_owner',
            field=models.PositiveIntegerField(
                blank=True, help_text='Per-user incrementing number', null=True),
        ),
        migrations.AddField(
            model_name='flash',
            name='id_owner',
            field=models.PositiveIntegerField(
                blank=True, help_text='Per-user incrementing number', null=True),
        ),
        migrations.AddField(
            model_name='lens',
            name='id_owner',
            field=models.PositiveIntegerField(
                blank=True, help_text='Per-user incrementing number', null=True),
        ),
        migrations.AddField(
            model_name='mountadapter',
            name='id_owner',
            field=models.PositiveIntegerField(
                blank=True, help_text='Per-user incrementing number', null=True),
        ),
        migrations.AddField(
            model_name='negative',
            name='id_owner',
            field=models.PositiveIntegerField(
                blank=True, help_text='Per-user incrementing number', null=True),
        ),
        migrations.AddField(
            model_name='order',
            name='id_owner',
            field=models.PositiveIntegerField(
                blank=True, help_text='Per-user incrementing number', null=True),
        ),
        migrations.AddField(
            model_name='person',
            name='id_owner',
            field=models.PositiveIntegerField(
                blank=True, help_text='Per-user incrementing number', null=True),
        ),
        migrations.AddField(
            model_name='print',
            name='id_owner',
            field=models.PositiveIntegerField(
                blank=True, help_text='Per-user incrementing number', null=True),
        ),
        migrations.AddField(
            model_name='repair',
            name='id_owner',
            field=models.PositiveIntegerField(
                blank=True, help_text='Per-user incrementing number', null=True),
        ),
        migrations.AddField(
            model_name='scan',
            name='id_owner',
            field=models.PositiveIntegerField(
                blank=True, help_text='Per-user incrementing number', null=True),
        ),
        migrations.AddField(
            model_name='series',
            name='id_owner',
            field=models.PositiveIntegerField(
                blank=True, help_text='Per-user incrementing number', null=True),
        ),
        migrations.AddField(
            model_name='teleconverter',
            name='id_owner',
            field=models.PositiveIntegerField(
                blank=True, help_text='Per-user incrementing number', null=True),
        ),
        migrations.AlterUniqueTogether(
            name='accessory',
            unique_together={('id_owner', 'owner')},
        ),
        migrations.AlterUniqueTogether(
            name='archive',
            unique_together={('id_owner', 'owner')},
        ),
        migrations.AlterUniqueTogether(
            name='bulkfilm',
            unique_together={('id_owner', 'owner')},
        ),
        migrations.AlterUniqueTogether(
            name='camera',
            unique_together={('id_owner', 'owner'), ('cameramodel', 'serial')},
        ),
        migrations.AlterUniqueTogether(
            name='enlarger',
            unique_together={('id_owner', 'owner')},
        ),
        migrations.AlterUniqueTogether(
            name='film',
            unique_together={('id_owner', 'owner')},
        ),
        migrations.AlterUniqueTogether(
            name='filter',
            unique_together={('id_owner', 'owner')},
        ),
        migrations.AlterUniqueTogether(
            name='flash',
            unique_together={('id_owner', 'owner')},
        ),
        migrations.AlterUniqueTogether(
            name='lens',
            unique_together={('id_owner', 'owner'), ('lensmodel', 'serial')},
        ),
        migrations.AlterUniqueTogether(
            name='mountadapter',
            unique_together={('id_owner', 'owner')},
        ),
        migrations.AlterUniqueTogether(
            name='negative',
            unique_together={('id_owner', 'owner'), ('film', 'frame')},
        ),
        migrations.AlterUniqueTogether(
            name='order',
            unique_together={('id_owner', 'owner')},
        ),
        migrations.AlterUniqueTogether(
            name='person',
            unique_together={('id_owner', 'owner')},
        ),
        migrations.AlterUniqueTogether(
            name='print',
            unique_together={('id_owner', 'owner')},
        ),
        migrations.AlterUniqueTogether(
            name='repair',
            unique_together={('id_owner', 'owner')},
        ),
        migrations.AlterUniqueTogether(
            name='scan',
            unique_together={('id_owner', 'owner')},
        ),
        migrations.AlterUniqueTogether(
            name='series',
            unique_together={('id_owner', 'owner')},
        ),
        migrations.AlterUniqueTogether(
            name='teleconverter',
            unique_together={('id_owner', 'owner')},
        ),
    ]



# Generated by Django 2.2 on 2020-03-09 21:40

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0027_auto_20200306_2156'),
    ]

    operations = [
        migrations.AddField(
            model_name='cameramodel',
            name='x_sync',
            field=models.ForeignKey(blank=True, help_text='Flash X-sync speed', null=True,
                                    on_delete=django.db.models.deletion.CASCADE, related_name='x_sync', to='schema.ShutterSpeed'),
        ),
    ]



# Generated by Django 2.2 on 2020-03-21 23:30

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0039_auto_20200321_2236'),
    ]

    operations = [
        migrations.AlterField(
            model_name='developer',
            name='manufacturer',
            field=models.ForeignKey(help_text='Manufacturer of this developer',
                                    on_delete=django.db.models.deletion.CASCADE, to='schema.Manufacturer'),
        ),
        migrations.AlterField(
            model_name='filmstock',
            name='manufacturer',
            field=models.ForeignKey(help_text='Manufacturer of this film',
                                    on_delete=django.db.models.deletion.CASCADE, to='schema.Manufacturer'),
        ),
        migrations.AlterField(
            model_name='lensmodel',
            name='manufacturer',
            field=models.ForeignKey(help_text='Manufacturer of this lens model',
                                    on_delete=django.db.models.deletion.CASCADE, to='schema.Manufacturer'),
        ),
        migrations.AlterField(
            model_name='toner',
            name='manufacturer',
            field=models.ForeignKey(help_text='Manufacturer of this toner',
                                    on_delete=django.db.models.deletion.CASCADE, to='schema.Manufacturer'),
        ),
        migrations.AlterUniqueTogether(
            name='lensmodel',
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name='developer',
            constraint=models.UniqueConstraint(
                fields=('manufacturer', 'name'), name='developer_unique_name'),
        ),
        migrations.AddConstraint(
            model_name='filmstock',
            constraint=models.UniqueConstraint(
                fields=('manufacturer', 'name'), name='filmstock_unique_name'),
        ),
        migrations.AddConstraint(
            model_name='lensmodel',
            constraint=models.UniqueConstraint(fields=(
                'manufacturer', 'model', 'disambiguation'), name='lensmodel_unique_name'),
        ),
        migrations.AddConstraint(
            model_name='toner',
            constraint=models.UniqueConstraint(
                fields=('manufacturer', 'name'), name='toner_unique_name'),
        ),
    ]



# Generated by Django 2.2.4 on 2019-10-16 10:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0009_auto_20191015_0926'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cameramodel',
            name='video',
        ),
        migrations.RemoveField(
            model_name='projector',
            name='cine',
        ),
        migrations.DeleteModel(
            name='Movie',
        ),
    ]



# Generated by Django 2.2.9 on 2020-03-31 14:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0050_auto_20200327_2303'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cameramodel',
            name='series',
        ),
        migrations.RemoveField(
            model_name='lensmodel',
            name='series',
        ),
        migrations.DeleteModel(
            name='Series',
        ),
    ]



# Generated by Django 2.2.14 on 2020-08-10 18:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0068_auto_20200708_2109'),
    ]

    operations = [
        migrations.AddField(
            model_name='cameramodel',
            name='self_timer',
            field=models.BooleanField(blank=True, help_text='Whether the camera has a self-timer', null=True),
        ),
        migrations.AddField(
            model_name='historicalcameramodel',
            name='self_timer',
            field=models.BooleanField(blank=True, help_text='Whether the camera has a self-timer', null=True),
        ),
    ]



# Generated by Django 2.2 on 2020-04-17 19:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0051_auto_20200331_1448'),
    ]

    operations = [
        migrations.AddField(
            model_name='cameramodel',
            name='url',
            field=models.URLField(blank=True, help_text='URL to more information about this camera model', null=True, verbose_name='URL'),
        ),
    ]



# Generated by Django 2.2.14 on 2020-08-20 20:03

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0073_auto_20200818_2118'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cameramodel',
            name='rectilinear',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='rectilinear',
        ),
        migrations.RemoveField(
            model_name='historicallensmodel',
            name='rectilinear',
        ),
        migrations.RemoveField(
            model_name='lensmodel',
            name='rectilinear',
        ),
    ]



# Generated by Django 2.2.9 on 2020-03-17 14:10

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0031_auto_20200317_1404'),
    ]

    operations = [
        migrations.AddField(
            model_name='battery',
            name='compatible_with',
            field=models.ManyToManyField(blank=True, to='schema.Battery'),
        ),
    ]



from django.db import migrations


def forwards_func(apps, schema_editor):
    # We get the model from the versioned app registry;
    # if we directly import it, it'll be the wrong version
    db_alias = schema_editor.connection.alias

    Format = apps.get_model("schema", "Format")
    Format.objects.using(db_alias).bulk_create([
        Format(format="120 roll"),
        Format(format="135 roll"),
        Format(format="620 roll"),
        Format(format="APS-C"),
        Format(format="Quarter plate"),
        Format(format="Polaroid 600"),
        Format(format="2.25x3.25\" sheet"),
        Format(format="6.5x9 sheet"),
        Format(format="4x5\" sheet"),
        Format(format="126 cartridge"),
        Format(format="110 cartridge"),
        Format(format="3¼x4\""),
        Format(format="116 roll"),
        Format(format="127 roll"),
    ])


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0004_manufacturers'),
    ]

    operations = [
        migrations.RunPython(forwards_func),
    ]



from __future__ import unicode_literals
from django.db import migrations, models
from slugify import UniqueSlugify


def addCustom(apps, schema_editor):

    ExistingRecords = apps.get_model('schema', 'cameramodel')

    custom_slugify_unique = UniqueSlugify(to_lower=True)

    for record in ExistingRecords.objects.all():
        record.slug = custom_slugify_unique("{} {} {}".format(
            record.manufacturer.name, record.model, str(record.disambiguation or '')))
        record.save()


class Migration(migrations.Migration):
    dependencies = [
        ('schema', '0035_cameramodel_slug'),
    ]
    operations = [
        migrations.RunPython(
            addCustom, reverse_code=migrations.RunPython.noop),
    ]



# Generated by Django 2.2 on 2020-03-23 22:36

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django_currentuser.db.models.fields
import django_currentuser.middleware


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('schema', '0046_auto_20200323_2226'),
    ]

    operations = [
        migrations.AddField(
            model_name='lensmodel',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AddField(
            model_name='lensmodel',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, editable=False,
                                                                       null=True, on_delete=django.db.models.deletion.CASCADE, related_name='lensmodel_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AddField(
            model_name='lensmodel',
            name='updated_at',
            field=models.DateTimeField(auto_now=True, null=True),
        ),
        migrations.AddField(
            model_name='lensmodel',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='lensmodel_updated_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='cameramodel',
            name='created_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, editable=False,
                                                                       null=True, on_delete=django.db.models.deletion.CASCADE, related_name='cameramodel_created_by', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='cameramodel',
            name='updated_by',
            field=django_currentuser.db.models.fields.CurrentUserField(default=django_currentuser.middleware.get_current_authenticated_user, null=True,
                                                                       on_delete=django.db.models.deletion.CASCADE, on_update=True, related_name='cameramodel_updated_by', to=settings.AUTH_USER_MODEL),
        ),
    ]



# Generated by Django 2.2.14 on 2020-08-28 21:43

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0081_remove_cameramodel_shutter_speeds'),
    ]

    operations = [
        migrations.AlterField(
            model_name='shutterspeed',
            name='shutter_speed',
            field=models.CharField(help_text='Shutter speed in fractional notation, e.g. 1/250', max_length=10, primary_key=True, serialize=False, validators=[django.core.validators.RegexValidator(message='Shutter speed must be expressed like 1/125, 2, or 2.5', regex='^\\d+(/\\d+(\\.\\d+)?)?$')]),
        ),
    ]



from django_filters import FilterSet, CharFilter
from django_currentuser.middleware import get_current_user
from taggit.forms import TagField

# Import all models that need admin pages
from schema.models import Accessory, Archive, Battery, BulkFilm, Camera, CameraModel, Developer, Enlarger, EnlargerModel, FilmStock
from schema.models import Flash, FlashModel, Lens, LensModel
from schema.models import Mount, MountAdapter, Order, PaperStock, Print
from schema.models import Negative, Film, Teleconverter, TeleconverterModel, Toner

# Define a custom tag filter


class TagFilter(CharFilter):
    field_class = TagField

    def __init__(self, *args, **kwargs):
        kwargs.setdefault('lookup_expr', 'in')
        super().__init__(*args, **kwargs)


class AccessoryFilter(FilterSet):
    class Meta:
        model = Accessory
        fields = ('type',)

    @property
    def qs(self):
        parent = super().qs
        return parent.filter(owner=get_current_user())


class ArchiveFilter(FilterSet):
    class Meta:
        model = Archive
        fields = ('type', 'location', 'storage', 'sealed')

    @property
    def qs(self):
        parent = super().qs
        return parent.filter(owner=get_current_user())


class BatteryFilter(FilterSet):
    class Meta:
        model = Battery
        fields = ('chemistry',)


class BulkFilmFilter(FilterSet):
    class Meta:
        model = BulkFilm
        fields = ('format', 'filmstock',)

    @property
    def qs(self):
        parent = super().qs
        return parent.filter(owner=get_current_user())


class CameraFilter(FilterSet):
    class Meta:
        model = Camera
        fields = [
            'cameramodel__manufacturer',
            'cameramodel__mount',
            'cameramodel__format',
            'cameramodel__negative_size',
            'cameramodel__body_type',
            'own',
        ]

    @property
    def qs(self):
        parent = super().qs
        return parent.filter(owner=get_current_user())


class CameraModelFilter(FilterSet):
    tags = TagFilter(field_name='tags__name', label='Tags')

    class Meta:
        model = CameraModel
        fields = [
            'manufacturer',
            'mount',
            'format',
            'negative_size',
            'body_type',
        ]


class DeveloperFilter(FilterSet):
    tags = TagFilter(field_name='tags__name', label='Tags')

    class Meta:
        model = Developer
        fields = ('manufacturer', 'for_paper', 'for_film')


class EnlargerModelFilter(FilterSet):
    class Meta:
        model = EnlargerModel
        fields = ('manufacturer', 'negative_size', 'type', 'light_source')

class EnlargerFilter(FilterSet):
    class Meta:
        model = Enlarger
        fields = ('enlargermodel', )

    @property
    def qs(self):
        parent = super().qs
        return parent.filter(owner=get_current_user())


class FilmStockFilter(FilterSet):
    tags = TagFilter(field_name='tags__name', label='Tags')

    class Meta:
        model = FilmStock
        fields = ('manufacturer', 'colour', 'panchromatic', 'process')


class FlashModelFilter(FilterSet):
    class Meta:
        model = FlashModel
        fields = ('manufacturer',
                  'pc_sync',
                  'hot_shoe',
                  'light_stand',
                  'manual_control',
                  'swivel_head',
                  'tilt_head',
                  'zoom',
                  'ttl',
                  )

class FlashFilter(FilterSet):
    class Meta:
        model = Flash
        fields = ('flashmodel',)

    @property
    def qs(self):
        parent = super().qs
        return parent.filter(owner=get_current_user())


class LensFilter(FilterSet):
    class Meta:
        model = Lens
        fields = ('lensmodel__manufacturer',
                  'lensmodel__mount',
                  'lensmodel__zoom',
                  'lensmodel__autofocus',
                  'own',
                  )

    @property
    def qs(self):
        parent = super().qs
        return parent.filter(owner=get_current_user())


class LensModelFilter(FilterSet):
    tags = TagFilter(field_name='tags__name', label='Tags')

    class Meta:
        model = LensModel
        fields = ('manufacturer', 'mount', 'zoom', 'autofocus', 'lens_type')


class MountFilter(FilterSet):
    tags = TagFilter(field_name='tags__name', label='Tags')

    class Meta:
        model = Mount
        fields = ('shutter_in_lens', 'type', 'purpose')


class MountAdapterFilter(FilterSet):
    class Meta:
        model = MountAdapter
        fields = ('camera_mount', 'lens_mount',
                  'has_optics', 'infinity_focus',)

    @property
    def qs(self):
        parent = super().qs
        return parent.filter(owner=get_current_user())


class OrderFilter(FilterSet):
    class Meta:
        model = Order
        fields = ('printed',)

    @property
    def qs(self):
        parent = super().qs
        return parent.filter(owner=get_current_user())


class PaperStockFilter(FilterSet):
    tags = TagFilter(field_name='tags__name', label='Tags')

    class Meta:
        model = PaperStock
        fields = ('manufacturer', 'resin_coated', 'colour', 'finish')


class PrintFilter(FilterSet):
    class Meta:
        model = Print
        fields = [
            'paper_stock',
            'developer',
            'fine',
            'archive',
        ]

    @property
    def qs(self):
        parent = super().qs
        return parent.filter(owner=get_current_user())


class NegativeFilter(FilterSet):
    class Meta:
        model = Negative
        fields = [
            'film',
            'lens',
        ]

    @property
    def qs(self):
        parent = super().qs
        return parent.filter(owner=get_current_user())


class FilmFilter(FilterSet):
    class Meta:
        model = Film
        fields = [
            'filmstock',
            'format',
            'status',
            'camera',
            'bulk_film',
            'archive',
        ]

    @property
    def qs(self):
        parent = super().qs
        return parent.filter(owner=get_current_user())


class TeleconverterFilter(FilterSet):
    class Meta:
        model = Teleconverter
        fields = ('teleconvertermodel',)

    @property
    def qs(self):
        parent = super().qs
        return parent.filter(owner=get_current_user())

class TeleconverterModelFilter(FilterSet):
    class Meta:
        model = TeleconverterModel
        fields = ('manufacturer', 'mount',)


class TonerFilter(FilterSet):
    tags = TagFilter(field_name='tags__name', label='Tags')

    class Meta:
        model = Toner
        fields = ('manufacturer',)



# Generated by Django 2.2.4 on 2019-11-07 20:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0015_auto_20191107_1108'),
    ]

    operations = [
        migrations.AlterField(
            model_name='lensmodel',
            name='url',
            field=models.URLField(
                blank=True, help_text='URL to more information about this lens', null=True, verbose_name='URL'),
        ),
    ]



# Generated by Django 2.2 on 2020-03-20 22:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0034_auto_20200317_2149'),
    ]

    operations = [
        migrations.AddField(
            model_name='cameramodel',
            name='slug',
            field=models.SlugField(editable=False, null=True, unique=True),
        ),
    ]



from django.db import migrations


def forwards_func(apps, schema_editor):
    # We get the model from the versioned app registry;
    # if we directly import it, it'll be the wrong version
    db_alias = schema_editor.connection.alias

    Mount = apps.get_model("schema", "Mount")
    Manufacturer = apps.get_model("schema", "Manufacturer")

    Manufacturer.objects.using(db_alias).bulk_create([
        Manufacturer(name="Alpa", country="Switzerland",
                     url="http://www.alpa.ch"),
        Manufacturer(name="Bronica", city="Tokyo",
                     country="Japan", founded="1956"),
        Manufacturer(name="Hasselblad", city="Gothenburg", country="Sweden",
                     url="https://www.hasselblad.com", founded="1841"),
        Manufacturer(name="Ihagee", city="Dresden",
                     country="Germany", founded="1912"),
        Manufacturer(name="Kowa", country="Japan", founded="1954"),
        Manufacturer(name="Petri", country="Japan", founded="1907"),
    ], ignore_conflicts=True)

    Alpa = Manufacturer.objects.get(name='Alpa')
    Mount.objects.using(db_alias).update_or_create(
        mount="Alpa", type='Bayonet', purpose='Camera', manufacturer=Alpa)

    Braun = Manufacturer.objects.get(name='Braun')
    Mount.objects.using(db_alias).update_or_create(
        mount="Paxette", shutter_in_lens=0, type='Screw', purpose='Camera', manufacturer=Braun)

    Bronica = Manufacturer.objects.get(name='Bronica')
    Mount.objects.using(db_alias).update_or_create(
        mount="Bronica ETR", type='Bayonet', purpose='Camera', manufacturer=Bronica)
    Mount.objects.using(db_alias).update_or_create(
        mount="Bronica GS1", type='Bayonet', purpose='Camera', manufacturer=Bronica)
    Mount.objects.using(db_alias).update_or_create(
        mount="Bronica RF", type='Bayonet', purpose='Camera', manufacturer=Bronica)
    Mount.objects.using(db_alias).update_or_create(
        mount="Bronica SQA", type='Bayonet', purpose='Camera', manufacturer=Bronica)

    Canon = Manufacturer.objects.get(name='Canon')
    Mount.objects.using(db_alias).update_or_create(
        mount="Canon EF", shutter_in_lens=0, type='Bayonet', purpose='Camera', manufacturer=Canon)
    Mount.objects.using(db_alias).update_or_create(
        mount="Canon EF-M", shutter_in_lens=0, type='Bayonet', purpose='Camera', manufacturer=Canon)
    Mount.objects.using(db_alias).update_or_create(
        mount="Canon EF-S", shutter_in_lens=0, type='Bayonet', purpose='Camera', manufacturer=Canon)
    Mount.objects.using(db_alias).update_or_create(
        mount="Canon EX", shutter_in_lens=0, type='Bayonet', purpose='Camera', manufacturer=Canon)
    Mount.objects.using(db_alias).update_or_create(
        mount="Canon FD", shutter_in_lens=0, type='Breech lock', purpose='Camera', manufacturer=Canon)
    Mount.objects.using(db_alias).update_or_create(
        mount="Canon FL", shutter_in_lens=0, type='Breech lock', purpose='Camera', manufacturer=Canon)

    Fuji = Manufacturer.objects.get(name='Fuji')
    Mount.objects.using(db_alias).update_or_create(
        mount="Fujica X", type='Bayonet', purpose='Camera', manufacturer=Fuji)

    Hasselblad = Manufacturer.objects.get(name='Hasselblad')
    Mount.objects.using(db_alias).update_or_create(
        mount="Hasselblad", type='Bayonet', purpose='Camera', manufacturer=Hasselblad)
    Mount.objects.using(db_alias).update_or_create(
        mount="Hasselblad Xpan", type='Bayonet', purpose='Camera', manufacturer=Hasselblad)

    Ihagee = Manufacturer.objects.get(name='Ihagee')
    Mount.objects.using(db_alias).update_or_create(
        mount="Exakta", type='Bayonet', purpose='Camera', manufacturer=Ihagee)

    Konica = Manufacturer.objects.get(name='Konica')
    Mount.objects.using(db_alias).update_or_create(
        mount="KM", type='Bayonet', purpose='Camera', manufacturer=Konica)
    Mount.objects.using(db_alias).update_or_create(
        mount="Konica AR", type='Bayonet', purpose='Camera', manufacturer=Konica)
    Mount.objects.using(db_alias).update_or_create(
        mount="Konica F", type='Bayonet', purpose='Camera', manufacturer=Konica)

    Kowa = Manufacturer.objects.get(name='Kowa')
    Mount.objects.using(db_alias).update_or_create(
        mount="Kowa Six", type='Breech lock', purpose='Camera', manufacturer=Kowa)

    Leitz = Manufacturer.objects.get(name='Leitz')
    Mount.objects.using(db_alias).update_or_create(
        mount="Leica M", shutter_in_lens=0, type='Bayonet', purpose='Camera', manufacturer=Leitz)
    Mount.objects.using(db_alias).update_or_create(
        mount="Leica R", shutter_in_lens=0, type='Bayonet', purpose='Camera', manufacturer=Leitz)

    Mamiya = Manufacturer.objects.get(name='Mamiya')
    Mount.objects.using(db_alias).update_or_create(
        mount="Mamiya 6", type='Bayonet', purpose='Camera', manufacturer=Mamiya)
    Mount.objects.using(db_alias).update_or_create(
        mount="Mamiya 645", type='Bayonet', purpose='Camera', manufacturer=Mamiya)
    Mount.objects.using(db_alias).update_or_create(
        mount="Mamiya 7/7II", type='Bayonet', purpose='Camera', manufacturer=Mamiya)
    Mount.objects.using(db_alias).update_or_create(
        mount="Mamiya RB67", shutter_in_lens=1, type='Bayonet', purpose='Camera', manufacturer=Mamiya)
    Mount.objects.using(db_alias).update_or_create(
        mount="Mamiya RZ67", shutter_in_lens=1, type='Bayonet', purpose='Camera', manufacturer=Mamiya)
    Mount.objects.using(db_alias).update_or_create(
        mount="Mamiya ZE", shutter_in_lens=0, type='Bayonet', purpose='Camera', manufacturer=Mamiya)
    Mount.objects.using(db_alias).update_or_create(mount="Mamiya/Sekor E",
                                                   shutter_in_lens=0, type='Bayonet', purpose='Camera', manufacturer=Mamiya)

    Minolta = Manufacturer.objects.get(name='Minolta')
    Mount.objects.using(db_alias).update_or_create(
        mount="Minolta A", type='Bayonet', purpose='Camera', manufacturer=Minolta)
    Mount.objects.using(db_alias).update_or_create(
        mount="Minolta SR", type='Bayonet', purpose='Camera', manufacturer=Minolta)
    Mount.objects.using(db_alias).update_or_create(
        mount="Miranda M44", type='Bayonet', purpose='Camera', manufacturer=Minolta)

    Nikon = Manufacturer.objects.get(name='Nikon')
    Mount.objects.using(db_alias).update_or_create(
        mount="Nikon F", shutter_in_lens=0, type='Bayonet', purpose='Camera', manufacturer=Nikon)
    Mount.objects.using(db_alias).update_or_create(
        mount="Nikon S", shutter_in_lens=0, type='Bayonet', purpose='Camera', manufacturer=Nikon)

    Olympus = Manufacturer.objects.get(name='Olympus')
    Mount.objects.using(db_alias).update_or_create(
        mount="Olympus OM", shutter_in_lens=0, type='Bayonet', purpose='Camera', manufacturer=Olympus)
    Mount.objects.using(db_alias).update_or_create(
        mount="Olympus Pen F", type='Bayonet', purpose='Camera', manufacturer=Olympus)

    Pentacon = Manufacturer.objects.get(name='Pentacon')
    Mount.objects.using(db_alias).update_or_create(
        mount="Pentacon Six", type='Breech lock', purpose='Camera', manufacturer=Pentacon)
    Mount.objects.using(db_alias).update_or_create(
        mount="Praktica", type='Bayonet', purpose='Camera', manufacturer=Pentacon)
    Mount.objects.using(db_alias).update_or_create(
        mount="Praktina", type='Breech lock', purpose='Camera', manufacturer=Pentacon)

    Pentax = Manufacturer.objects.get(name='Pentax')
    Mount.objects.using(db_alias).update_or_create(
        mount="Pentax 110", type='Bayonet', purpose='Camera', manufacturer=Pentax)
    Mount.objects.using(db_alias).update_or_create(
        mount="Pentax 645", type='Bayonet', purpose='Camera', manufacturer=Pentax)
    Mount.objects.using(db_alias).update_or_create(
        mount="Pentax 6x7", type='Bayonet', purpose='Camera', manufacturer=Pentax)
    Mount.objects.using(db_alias).update_or_create(
        mount="Pentax K", type='Bayonet', purpose='Camera', manufacturer=Pentax)

    Petri = Manufacturer.objects.get(name='Petri')
    Mount.objects.using(db_alias).update_or_create(
        mount="Petriflex", type='Breech lock', purpose='Camera', manufacturer=Petri)

    Rollei = Manufacturer.objects.get(name='Rollei')
    Mount.objects.using(db_alias).update_or_create(
        mount="Rolleiflex SL35", type='Bayonet', purpose='Camera', manufacturer=Rollei)
    Mount.objects.using(db_alias).update_or_create(
        mount="Rolleiflex SL66", type='Bayonet', purpose='Camera', manufacturer=Rollei)

    Sigma = Manufacturer.objects.get(name='Sigma')
    Mount.objects.using(db_alias).update_or_create(
        mount="Sigma SA", shutter_in_lens=0, type='Bayonet', purpose='Camera', manufacturer=Sigma)

    Tamron = Manufacturer.objects.get(name='Tamron')
    Mount.objects.using(db_alias).update_or_create(
        mount="Adaptall", shutter_in_lens=0, type='Bayonet', purpose='Camera', manufacturer=Tamron)

    Zeiss = Manufacturer.objects.get(name='Zeiss Ikon')
    Mount.objects.using(db_alias).update_or_create(
        mount="Contax G", type='Breech lock', purpose='Camera', manufacturer=Zeiss)
    Mount.objects.using(db_alias).update_or_create(
        mount="Contax N", type='Bayonet', purpose='Camera', manufacturer=Zeiss)
    Mount.objects.using(db_alias).update_or_create(
        mount="Contax RF", type='Bayonet', purpose='Camera', manufacturer=Zeiss)
    Mount.objects.using(db_alias).update_or_create(
        mount="Contax/Yashica", type='Bayonet', purpose='Camera', manufacturer=Zeiss)

    Mount.objects.using(db_alias).update_or_create(
        mount="C", shutter_in_lens=0, type='Screw', purpose='Camera')
    Mount.objects.using(db_alias).update_or_create(
        mount="M25 Biological", type='Screw', purpose='Camera')
    Mount.objects.using(db_alias).update_or_create(
        mount="M37", type='Screw', purpose='Camera')
    Mount.objects.using(db_alias).update_or_create(
        mount="M39 (Enlarger)", type='Screw', purpose='Enlarger')
    Mount.objects.using(db_alias).update_or_create(
        mount="M39 (Rangefinder)", shutter_in_lens=0, type='Screw', purpose='Camera')
    Mount.objects.using(db_alias).update_or_create(
        mount="M39 (SLR)", shutter_in_lens=0, type='Screw', purpose='Camera')
    Mount.objects.using(db_alias).update_or_create(
        mount="M42", shutter_in_lens=0, type='Screw', purpose='Camera')
    Mount.objects.using(db_alias).update_or_create(
        mount="Praktiflex", type='Screw', purpose='Camera')
    Mount.objects.using(db_alias).update_or_create(
        mount="T/T2", shutter_in_lens=0, type='Screw', purpose='Camera')


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0006_negative_sizes'),
    ]

    operations = [
        migrations.RunPython(forwards_func),
    ]



from __future__ import unicode_literals
from django.db import migrations, models
from django.contrib.auth.models import User
import os


def forwards_func(apps, schema_editor):
    User.objects.create_superuser('admin', email=os.getenv(
        'CAMERAHUB_ADMIN_EMAIL', 'admin@example.com'), password=os.getenv('CAMERAHUB_ADMIN_PASSWORD', 'admin'))


def reverse_func(apps, schema_editor):
    # destroy what forward_func builds
    pass


class Migration(migrations.Migration):
    dependencies = [
        ('schema', '0019_auto_20200110_1728_squashed_0020_auto_20200110_1734'),
    ]
    operations = [
        migrations.RunPython(forwards_func, reverse_func),
    ]



# Generated by Django 2.2 on 2020-03-23 19:36

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0041_slugs'),
    ]

    operations = [
        migrations.AddField(
            model_name='cameramodel',
            name='mirror_lockup',
            field=models.BooleanField(
                blank=True, help_text='Whether the camera has mirror lock-up', null=True, verbose_name='Mirror lock-up'),
        ),
    ]
